KeepsakeError

Enum KeepsakeError 

#[non_exhaustive]
pub enum KeepsakeError { EmptyIdentifier { field: &'static str, }, TenantIdTooLong { max: usize, actual: usize, }, TenantIdControlCharacter { code_point: u32, }, TenantIdNoncharacter { code_point: u32, }, TenantMismatch { expected: TenantId, actual: TenantId, }, InvalidFulfillmentThreshold, RelationDisabled { relation_id: Uuid, }, DuplicateActiveKeepsake { subject_kind: String, subject_id: String, relation_id: Uuid, }, InvalidKeepsakeLifecycle { reason: &'static str, }, ActiveRelationMismatch { keepsake_relation_id: Uuid, relation_id: Uuid, }, InactiveActiveRelation { keepsake_id: Uuid, }, }
Errors returned by the core model contracts.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyIdentifier

A caller supplied an empty identifier.

Fields

field: &'static str

Field name.



TenantIdTooLong

A tenant identifier exceeded the storage contract’s byte limit.

Fields

max: usize

Maximum permitted UTF-8 byte length.

actual: usize

Supplied UTF-8 byte length.



TenantIdControlCharacter

A tenant identifier contained a Unicode control character.

Fields

code_point: u32

Unicode scalar value of the rejected character.



TenantIdNoncharacter

A tenant identifier contained a Unicode noncharacter.

Fields

code_point: u32

Unicode scalar value of the rejected character.



TenantMismatch

Two values from different tenants were combined.

Fields

expected: TenantId

Tenant required by the owning scope.

actual: TenantId

Tenant carried by the value being checked.



InvalidFulfillmentThreshold

A fulfillment policy cannot be satisfied because its threshold is invalid.



RelationDisabled

A command targets a disabled relation.

Fields

relation_id: Uuid

Disabled relation id.



DuplicateActiveKeepsake

A caller tried to apply a relation that is already active for a subject.

Fields

subject_kind: String

Subject kind.

subject_id: String

Subject id.

relation_id: Uuid

Relation id.



InvalidKeepsakeLifecycle

A flat keepsake record did not satisfy lifecycle invariants.

Fields

reason: &'static str

Validation failure reason.



ActiveRelationMismatch

An active relation paired a keepsake with the wrong relation definition.

Fields

keepsake_relation_id: Uuid

Relation id stored on the keepsake.

relation_id: Uuid

Relation id stored on the relation definition.



InactiveActiveRelation

An active relation was built from a non-active keepsake.

Fields

keepsake_id: Uuid

Keepsake id.